@@ -6,7 +6,7 @@ Mojo::Redis2 - Pure-Perl non-blocking I/O Redis driver
 
 =head1 VERSION
 
-0.12
+0.13
 
 =head1 DESCRIPTION
 
@@ -131,7 +131,7 @@ use Carp ();
 use constant DEBUG => $ENV{MOJO_REDIS_DEBUG} || 0;
 use constant DEFAULT_PORT => 6379;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 my $PROTOCOL_CLASS = do {
   my $class = $ENV{MOJO_REDIS_PROTOCOL} ||= eval "require Protocol::Redis::XS; 'Protocol::Redis::XS'" || 'Protocol::Redis';
@@ -486,7 +486,7 @@ sub _dequeue {
 
 sub _error {
   my ($self, $c, $err) = @_;
-  my $waiting = $c->{waiting} || [];
+  my $waiting = $c->{waiting} || $c->{queue};
 
   warn "[$c->{name}] !!! @{[$err // 'close']}\n" if DEBUG;
 
